﻿<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/user_input_handler_registry.php';

class DunehdEntryHandler
    implements UserInputHandler
{
    private $session;

    public function __construct($session)
    {
        $this->session = $session;

        UserInputHandlerRegistry::get_instance()->
            register_handler($this);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_handler_id()
    {
        return 'entry';
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Entry handler: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if (!isset($user_input->entry_id))
            return null;

		$this->session->manual_started();

        $add_params = array(
            'entry_id' => $user_input->entry_id);

        if ($user_input->entry_id === 'setup' || $user_input->entry_id === 'tv')
        {
            $res = $this->session->apply_subscription($plugin_cookies, $user_input);
			$this->session->invalidate_channels();
            if ($res !== false)
            {
                if (!isset($res['action']))
                {
                    return ActionFactory::close_dialog_and_run(
                        ActionFactory::open_folder());
                }

                return $res['need_close_dialog'] ?
                    ActionFactory::close_dialog_and_run($res['action']) :
                    $res['action'];
            }
            else
            {
                if ($this->session->is_logged_in())
				{
					if($user_input->entry_id !== 'setup')
					{
						$check = $this->session->check_subscriptions();
						if($check !== false)
						{
							$defs = $check['dialog'];
							if($check['result'] == 'STOPED')
							{
								ControlFactory::add_custom_close_dialog_and_apply_button($defs, "name", $this->session->translate('subscription_data'), NULL, $this->session->do_get_edit_subscription_action(
									$plugin_cookies, $this, $add_params));
							}
							return ActionFactory::show_dialog(
								$this->session->translate('subscription_date'),
								$defs,
								true);
						}
					}
                    return ActionFactory::open_folder();
				}
				
				if(!isset($plugin_cookies->user_name) || $plugin_cookies->user_name === '')
                {
                    return $this->session->do_get_edit_subscription_action(
                        $plugin_cookies, $this, $add_params);
                }

                if ($user_input->entry_id === 'setup')
                    return ActionFactory::open_folder();

                hd_print('Entry handler: handle_user_input: try_login');
                $post_action = null;
                try
                {
                    $this->session->try_login($plugin_cookies);					
					if($user_input->entry_id !== 'setup')
					{
						$check = $this->session->check_subscriptions();
						if($check !== false)
						{
							$defs = $check['dialog'];
							if($check['result'] == 'STOPED')
							{
								ControlFactory::add_custom_close_dialog_and_apply_button($defs, "name", $this->session->translate('subscription_data') . $check['result'], NULL, $this->session->do_get_edit_subscription_action(
									$plugin_cookies, $this, $add_params));
							}
							return ActionFactory::show_dialog(
								$this->session->translate('subscription_date') . $check['result'],
								$defs,
								true);
						}
					}
                }
                catch (DuneException $e)
                {
                    hd_print('Entry handler: handle_user_input: exception - ' . $e->getMessage());
					if($e->getMessage() == 'Login failed.' && $user_input->entry_id === 'tv')
						return $this->session->do_get_edit_subscription_action(
							$plugin_cookies, $this, $add_params);
					
                    $post_action = $e->get_error_action();
                    return $post_action;
                }
                return ActionFactory::open_folder();
            }
        }

        return null;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
